@@ -47,4 +47,8 @@ if config.USE_UPY_IMAGE:
 if config.USE_CUSTOM_ADMIN:
     urlpatterns += patterns('',
         (r'', include('upy.contrib.customadmin.urls')),
+    )
+if config.USE_UPY_ROSETTA:
+    urlpatterns += patterns('',
+        (r'', include('upy.contrib.rosetta.urls')),
     )
\ No newline at end of file
